@@ -298,7 +298,7 @@ def shutdown_all(
     jobs = resp.json()
     cnt = len(jobs)
     for job in jobs:
-        job_url = url + "/" + job["job_id"]
+        job_url = url + "/" + str(job["job_id"])
         _ = ctx.obj.session.patch(job_url, json={"shutdown": True})
 
     if is_wait:
@@ -388,7 +388,7 @@ def cleanup(ctx: Context):
         except ServerError as e:
             if e.response["status_code"] == 404:
                 out(f"Deleting orphaned job {job['job_id']} on node {job['node_id']} in tenant {job['tenant']}")
-                job_url = jobs_url + "/" + job["job_id"]
+                job_url = jobs_url + "/" + str(job["job_id"])
                 _ = ctx.obj.session.delete(job_url)
                 n += 1
     if n:
