@@ -205,7 +205,10 @@ class ServiceSession(requests.Session):
         return response
 
     def get_url(self, subdomain):
-        return f"https://{subdomain}.{self.domain}"
+        if self.profile.urls:
+            return self.profile.urls[subdomain]
+        else:
+            return f"https://{subdomain}.{self.domain}"
 
     @property
     def kamo_url(self):
